==> comedi-0.6.2.tgz: comedi-0.6.2/module/rt.c <==
/*
    module/rt.c
    exported functions

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 1997-8 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/



#include <comedi_module.h>

#ifdef LINUX_V22
#define EXPORT_SYMTAB
#endif

#include <linux/module.h>
#include <linux/errno.h>
#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/fcntl.h>
#include <linux/delay.h>
#include <linux/ioport.h>
#include <linux/mm.h>
#include <linux/malloc.h>
#include <asm/io.h>
#include <asm/uaccess.h>


/*
	start of exported functions.  compilation chokes if this
	is in a separate file.
*/


int rtcomedi_open(int minor);
int rtcomedi_close(int minor);
int rtcomedi_lock(int minor,int subdev);
int rtcomedi_unlock(int minor,int subdev);
int rtcomedi_ioctl(int minor,int arg,void *p);

int rtcomedi_get(int minor,int chan,sampl_t *data);
int rtcomedi_put(int minor,int chan,sampl_t *data);



int rtcomedi_get(int minor,int chan,sampl_t *data)
{
	comedi_device *dev;
	comedi_trig t;
	int ret;
	
	if(minor<0 || minor>=COMEDI_NDEVICES)return -ENODEV;
	dev=comedi_devices+minor;
	if(!dev->rem)return -EINVAL;
	if(!dev->chinfo[chan].itrig)return -EINVAL;
	
	if(chan<0 || chan>=dev->chan)return -EINVAL;
	t.chan=chan;
	t.io=COMEDI_IO_INPUT;
	t.n=1;
	t.trigsrc=COMEDI_TRIGNOW;
	
	ret=dev->chinfo[chan].itrig(dev,&t);
	
	*data=t.data;
	
	return ret;
}

int rtcomedi_put(int minor,int chan,sampl_t *data)
{
	comedi_device *dev;
	comedi_trig t;
	int ret;

	if(minor<0 || minor>=COMEDI_NDEVICES)return -ENODEV;
	dev=comedi_devices+minor;
	if(!dev->rem)return -EINVAL;
	if(!dev->chinfo[chan].itrig)return -EINVAL;
	
	if(chan<0 || chan>=dev->chan)return -EINVAL;
	t.chan=chan;
	t.data=*data;
	t.io=COMEDI_IO_OUTPUT;
	t.n=0;
	t.trigsrc=COMEDI_TRIGNOW;
	
	ret=dev->chinfo[chan].itrig(dev,&t);
	
	return ret;
}
#endif

#ifdef LINUX_V20

/*
   need to generate modversions .def file for symbols if
   we want to use modversions and export them
*/
#ifndef CONFIG_MODVERSIONS

static struct symbol_table comedi_syms = {
#include <linux/symtab_begin.h>
	X(comedi_get),
	X(comedi_put),
#include <linux/symtab_end.h>
};

#endif

#endif

#ifdef LINUX_V22

EXPORT_SYMBOL(comedi_get);
EXPORT_SYMBOL(comedi_put);

#endif

==> comedi-0.6.4.tgz: comedi-0.6.4/module/rt.c <==
/*
    module/rt.c
    exported functions

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 1997-8 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/



#include <comedi_module.h>

#ifdef LINUX_V22
#define EXPORT_SYMTAB
#endif

#include <linux/module.h>
#include <linux/errno.h>
#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/fcntl.h>
#include <linux/delay.h>
#include <linux/ioport.h>
#include <linux/mm.h>
#include <linux/malloc.h>
#include <asm/io.h>
#include <asm/uaccess.h>


/*
	start of exported functions.
*/


int rtcomedi_open(int minor);
int rtcomedi_close(int minor);
int rtcomedi_lock(int minor,int subdev);
int rtcomedi_unlock(int minor,int subdev);
int rtcomedi_ioctl(int minor,int arg,void *p);

int rtcomedi_get(int minor,int chan,sampl_t *data);
int rtcomedi_put(int minor,int chan,sampl_t *data);


int rtcomedi_open(unsigned int minor)
{
	comedi_device *dev;

	if(minor>=COMEDI_MAXDEVS)
		return -ENODEV;

	dev=comedi_devices+minor;

	if(!dev->used)
		return -ENODEV;

	return 0;
}

int rtcomedi_close(int minor)
{
	return 0;
}

int rtcomedi_lock(int minor,int subdev)
{
	return -EACCES;
}

int rtcomedi_unlock(int minor,int subdev)
{
	return -EACCES;
}

int rtcomedi_ioctl(int minor,int arg,void *p);

int rtcomedi_get(int minor,int chan,sampl_t *data)
{
#if 0
	comedi_device *dev;
	comedi_trig t;
	int ret;
	
	if(minor<0 || minor>=COMEDI_NDEVICES)return -ENODEV;
	dev=comedi_devices+minor;
	if(!dev->rem)return -EINVAL;
	if(!dev->chinfo[chan].itrig)return -EINVAL;
	
	if(chan<0 || chan>=dev->chan)return -EINVAL;
	t.chan=chan;
	t.io=COMEDI_IO_INPUT;
	t.n=1;
	t.trigsrc=COMEDI_TRIGNOW;
	
	ret=dev->chinfo[chan].itrig(dev,&t);
	
	*data=t.data;
	
	return ret;
#endif
	return -EINVAL;
}

int rtcomedi_put(int minor,int chan,sampl_t *data)
{
#if 0
	comedi_device *dev;
	comedi_trig t;
	int ret;

	if(minor<0 || minor>=COMEDI_NDEVICES)return -ENODEV;
	dev=comedi_devices+minor;
	if(!dev->rem)return -EINVAL;
	if(!dev->chinfo[chan].itrig)return -EINVAL;
	
	if(chan<0 || chan>=dev->chan)return -EINVAL;
	t.chan=chan;
	t.data=*data;
	t.io=COMEDI_IO_OUTPUT;
	t.n=0;
	t.trigsrc=COMEDI_TRIGNOW;
	
	ret=dev->chinfo[chan].itrig(dev,&t);
	
	return ret;
#endif
	return -EINVAL;
}


#ifdef LINUX_V20

/*
   need to generate modversions .def file for symbols if
   we want to use modversions and export them
*/
#ifndef CONFIG_MODVERSIONS

static struct symbol_table comedi_syms = {
#include <linux/symtab_begin.h>
	X(rtcomedi_get),
	X(rtcomedi_put),
#include <linux/symtab_end.h>
};

#endif

#endif

#ifdef LINUX_V22

EXPORT_SYMBOL(rtcomedi_get);
EXPORT_SYMBOL(rtcomedi_put);

#endif
